[bumpr]
file = udata_event_consumer/__init__.py
vcs = git
commit = true
tag = true
tag_format = v{version}
push = true
tests = make test
publish = make install
files =
    README.md

[bump]
unsuffix = true

[prepare]
part = patch
suffix = dev

[changelog]
file = CHANGELOG.md
bump = ## {version} ({date:%Y-%m-%d})
prepare = ## Current (in progress)
separator =
